# awsecsconnect

Tired of typing a series of `aws` cli commands to get the arns and container name I need, when trying
to just open up a shell in that container.  

Usage: `awsecsconnect`

Dependencies: This assumes that you have AWS Profile environment variables set up already, and that you can
execute the aws cli using `aws`.  

## Notes
This uses boto3 to get most of the details, but ultimately still depends on having the AWS CLI installed,
because the execution of an interactive shell is a whole client unto itself.
